@@ -26,6 +26,10 @@ def inspect_rfile(file_expr, tree_name, filter_expr=None, output_file=None,
         Inspect root files
     '''
     file_expr = file_expr.split(',')
+    if include_patterns is not None:
+        include_patterns = include_patterns.split(',')
+    if exclude_patterns is not None:
+        exclude_patterns = exclude_patterns.split(',')
     rinspector = RooInspector(tree_name, file_expr, filter_expr=filter_expr, verbosity=verbosity)
     rinspector.print_summary(include_patterns=include_patterns,
                              exclude_patterns=exclude_patterns,
