@@ -178,7 +178,7 @@ class UpperLimit2DPlot(AbstractPlot):
             draw_fn = ax.plot
  
         if draw_observed:
-            obs_limits = data['obs'].values
+            obs_limits = data['obs'].values * scale_factor
             handle_observed = draw_fn(indices, obs_limits, color=color_pallete['observed'], 
                                       label=labels['observed'], 
                                       marker=observed_marker,
